@@ -102,19 +102,18 @@ def enhanced_dir(arg, categorize=True, show_types=False, checks=False, interface
         data, keys = [dc.values(), dc_1.values()], [dc.keys(), dc_1.keys()]
         fig, axes = plt.subplots(1, 2)
         palette_color = seaborn.color_palette('bright')
-
-        axes[0].pie(data[0], labels=keys[0], colors=palette_color, autopct='%.0f%%')
-        axes[1].pie(data[1], labels=keys[1], colors=palette_color, autopct='%.0f%%')
-
+        axes[0].pie(data[0], labels=keys[0], colors=palette_color,
+                    autopct=lambda p: f'{int(round(p * sum(data[0]) / 100))}')
+        axes[1].pie(data[1], labels=keys[1], colors=palette_color,
+                    autopct=lambda p: f'{int(round(p * sum(data[1]) / 100))}')
         plt.subplots_adjust(left=0.1, bottom=0.1, right=0.9, top=0.9, wspace=0.2, hspace=0.4)
-
         plt.show()
 
     if show_arguments:
         import enhanced_dir
         for i, j in passed[f'{arg}'].items():
             for t in j:
-                return_list.append([f"""{arg}.{t}: {enhanced_dir.argument_inspector(f"{arg}.{t}", 
+                return_list.append([f"""{arg}.{t}: {enhanced_dir.argument_inspector(f"{arg}.{t}",
                                                                                     no_of_arguments=no_of_arguments,
                                                                                     show_output=False)}"""])
 
@@ -476,6 +475,17 @@ inspection_arguments = [1, 0, 1.2, 'abc', '1', '0', '1.2', '1/2', {1, 2, 3}, {'a
                         '(lambda x: x < 5)', 'range(2)', "enumerate('a')", '(iter([1, 2, 3]))', '(iter(range(5)))',
                         '(iter(reversed([1, 2, 3])))', '(iter({1, 2, 3}))', "(iter('abc'))", '(iter((1, 2, 3)))',
                         "(iter({'a': 1, 'b': 2}.items()))", "(iter(zip((0, 1, 2), 'abc')))",
-                        "(iter({'a': 1, 'b': 2}.keys()))",  "(iter({'a': 1, 'b': 2}.values()))",
+                        "(iter({'a': 1, 'b': 2}.keys()))", "(iter({'a': 1, 'b': 2}.values()))",
                         ({'a': 1, 'b': 2}.keys()), ({'a': 1, 'b': 2}.values()), ({'a': 1, 'b': 2}.items()),
                         "(iter(b'2'))", "(iter(b'a'))", '(iter(bytearray(1)))']
+
+
+def diff(arg1, arg2, p=0):
+    returned_dict = {f'{arg1} - {arg2}': set(dir(arg1)) - set(dir(arg2)),
+                     f'{arg2} - {arg1}': set(dir(arg2)) - set(dir(arg1)),
+                     f'{arg2} ^ {arg1}': set(dir(arg2)) ^ set(dir(arg1))}
+    if p == 1:
+        from pprint import pprint
+        pprint(returned_dict, compact=True, width=120)
+    else:
+        return returned_dict
